@@ -172,7 +172,7 @@ class EntityReduceMap:
 
 class DefaultEmitter(Emitter):
     def __init__(self, context: IngestionSessionContext, asset_num_sharding=8, entities_num_sharding=8,
-                 rels_num_sharding=8):
+                 rels_num_sharding=8, csv_separator: str = '|', null_value: str = 'NULL'):
 
         if asset_num_sharding < 1 or entities_num_sharding < 1 or rels_num_sharding < 1:
             raise RuntimeError('Invalid requested number of shards.')
@@ -203,6 +203,9 @@ class DefaultEmitter(Emitter):
         self.entity_map = {}
         self.rel_map = {}
 
+        self.csv_separator = csv_separator
+        self.null_value = null_value
+
     def __get_entities_fd(self, entity: Entity) -> IO:
         key = 'entities'
 
@@ -270,7 +273,7 @@ class DefaultEmitter(Emitter):
 
     def __write_asset(self, asset: Asset):
         f = self.__get_assets_fd(asset)
-        f.write(asset.to_csv_entry(self.ctx) + "\n")
+        f.write(asset.to_csv_entry(self.ctx, self.csv_separator, self.null_value) + "\n")
 
     def emit_entities(self, entities: typing.List[Entity]):
         if entities is None or len(entities) <= 0:
