@@ -95,7 +95,7 @@ class Asset:
     def payload_hash(self):
         return self.calculate_hash(self.payload_hash_fields)
 
-    def to_csv_entry(self, ctx: IngestionSessionContext):
+    def to_csv_entry(self, ctx: IngestionSessionContext, csv_separator: str, null_value: str):
         parts = []
 
         sorted_retrieved_by = sorted(self.retrieved_by.keys())
@@ -148,7 +148,9 @@ class Asset:
         parts.append(str(self.key_hash))
         parts.append(str(self.payload_hash))
 
-        return "|".join(parts)
+        return csv_separator.join(
+            [x.strip().replace(csv_separator, "").replace("\n", "").replace("\r", "") if x is not None else null_value
+             for x in parts])
 
 
 @dataclass
@@ -217,6 +219,7 @@ class Relationship:
     @property
     def identity(self):
         return hash(self.source_identity_uid) + hash(self.target_identity_uid) + hash(self.relationship_type)
+
     def to_proto(self) -> RelationshipEntry:
         return RelationshipEntry(
             source_identity_uid=self.source_identity_uid,
